# -*- coding: utf-8 -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2016 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU Affero General Public License as published by the Free
#  Software Foundation, either version 3 of the License, or (at your option)
#  any later version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
#  more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################
"""
Console Commands
"""

from __future__ import unicode_literals, absolute_import

import logging

from rattail import commands
from rattail.util import load_object


log = logging.getLogger(__name__)


class ImportBRdata(commands.NewImportSubcommand):
    """
    Import data from a BRdata export file.
    """
    name = 'import-brdata'
    description = __doc__.strip()

    def add_parser_args(self, parser):
        super(ImportBRdata, self).add_parser_args(parser)
        parser.add_argument('--handler', metavar='KEY', required=True,
                            help="Which import handler to use.  This determines which data file "
                            "will be read, and which models/fields may be imported, etc.  It must "
                            "be one of (lblout, itemfile, movement) and defaults to 'lblout'.")

    def get_handler_factory(self, args):
        spec = 'rattail_brdata.importing.lblout:LbloutImportHandler'
        if args:
            if args.handler == 'itemfile':
                spec = self.config.get('rattail.importing', 'brdata.itemfile.handler',
                                       default='rattail_brdata.importing.itemfile:ItemfileImportHandler')
            elif args.handler == 'movement':
                spec = self.config.get('rattail.importing', 'brdata.movement.handler',
                                       default='rattail_brdata.importing.movement:MovementImportHandler')
            else:
                if args.handler and args.handler != 'lblout':
                    log.warning("ignoring invalid handler arg, using 'lblout' instead: {}".format(repr(args.handler))) 
                spec = self.config.get('rattail.importing', 'brdata.lblout.handler',
                                       default='rattail_brdata.importing.lblout:LbloutImportHandler')
        return load_object(spec)
