# -*- coding: utf-8 -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2015 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU Affero General Public License as published by the Free
#  Software Foundation, either version 3 of the License, or (at your option)
#  any later version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
#  more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################
"""
Parser for ``lblout.txt``
"""

from __future__ import unicode_literals

import os

from rattail.files import count_lines
from rattail.csvutil import UnicodeDictReader


# TODO: This logic is identical to that for the itemfile parser.  Should we
# just have one parser?

def parse_lblout(path, encoding='cp1252', progress=None):
    """
    Parse the ``lblout.txt`` file from BRdata.
    """
    rows = []
    count = count_lines(path, encoding=encoding)
    if not count:
        return rows

    with open(path, 'rb') as f:
        reader = UnicodeDictReader(f, encoding=encoding)

        prog = None
        if progress:
            prog = progress("Parsing {0} from BRdata".format(repr(os.path.basename(path))), count)
        for i, data in enumerate(reader, 1):

            rows.append(data)

            if prog:
                prog.update(i)
        if prog:
            prog.destroy()

    return rows
