# -*- coding: utf-8 -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2015 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU Affero General Public License as published by the Free
#  Software Foundation, either version 3 of the License, or (at your option)
#  any later version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
#  more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################
"""
Data Import Utilities
"""

from __future__ import unicode_literals

import logging

from rattail.gpc import GPC


log = logging.getLogger(__name__)


def normalize_upc(upc):
    """
    Normalize a string UPC into a proper ``GPC`` instance.  This function is
    designed to handle data coming from e.g. BRdata's ``lblout.txt`` file and
    the like.
    """
    upc = unicode(int(upc.strip()))
    if len(upc) >= 12:
        if len(upc) != 13:
            log.warning("UPC has unexpected length of {0}: {1}".format(
                    len(upc), repr(upc)))
        upc = GPC(upc)
    else:
        upc = GPC(upc, calc_check_digit='upc')
    return upc
